@@ -24,3 +24,8 @@ else
 
 fi
 
+
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+
+
+echo -e "\e[1;32mhttps://github.com/openvinotoolkit/openvino/tree/master/tools\e[0m"
